==> webtrees-8.x-2.2.tar.gz: webtrees/modules/webtrees_views/src/Plugin/views/field/WebtreesIndividual.php <==
<?php

namespace Drupal\webtrees_views\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\ResultRow;

/**
 * Render a Webtrees invidual GEDCOM field.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("webtrees_individual")
 */
class WebtreesIndividual extends FieldPluginBase {
  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    // Override the alter text option to always alter the text.
    $options['gedcom_format'] = ['default' => 'name'];

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['gedcom_format'] = [
      '#title' => $this->t('GEDCOM Format'),
      '#options' => [
        'raw' => 'Raw',
        'name' => 'Name',
        'first' => 'First name',
        'last' => 'Last name',
        'id' => 'ID',
      ],
      '#type' => 'select',
      '#default_value' => $this->options['gedcom_format'],
      '#description' => $this->t('Choose how the GEDCOM record is presented.'),
//      '#fieldset' => 'style_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $value = $this->getValue($values);
    $format = $this->options['gedcom_format'];

    switch ($format) {
      case 'id':
        if (preg_match('"0 @(.*)@ INDI"',$value,$matches)) {
          return $matches[1];
        }
        return '';
      case 'name':
      case 'first':
      case 'last';
        // looking for "1 NAME William George /Wong/".
        // Matches include full string and each element.
        $matches = [];
        $first = '';
        $last = '';
        preg_match('"1 NAME (.*) /(.*)/"',$value,$matches);
        switch (sizeof($matches)) {
          case 0:
            return '';
          case 2:
            $first = $matches[1];
            break;
          default:
            $first = $matches[1];
            $last  = $matches[2];
            break;
        }

        switch ($format) {
          case 'first':
            return $first;
          case 'last';
            return $last;
          default:
            return "$first $last";
        }
      default:
        return $value;
    }
  }
}

==> webtrees-8.x-2.3.tar.gz: webtrees/modules/webtrees_views/src/Plugin/views/field/WebtreesIndividual.php <==
<?php

namespace Drupal\webtrees_views\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;

/**
 * Render a Webtrees invidual GEDCOM field.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("webtrees_individual")
 */
class WebtreesIndividual extends WebtreesFieldBase {
  /**
   * Webtress type used in path.
   *
   * @var string
   */
  public $webtreesType = 'individual';

  /**
   * Webtress index field.
   *
   * @var string
   */
  public $webtreesId = 'i_id';

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['gedcom_format'] = ['default' => 'name'];

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['gedcom_format'] = [
      '#title' => $this->t('GEDCOM Format'),
      '#options' => [
        'raw' => t('Raw'),
        'name' => t('Name'),
        'first' => t('First name'),
        'last' => t('Last name'),
        'id' => t('ID'),
        'link' => t('Link'),
      ],
      '#type' => 'select',
      '#default_value' => $this->options['gedcom_format'],
      '#description' => $this->t('Choose how the GEDCOM record is presented.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($values) {
    $value = $this->getValue($values);
    $format = $this->options['gedcom_format'];

    switch ($format) {
      case 'id':
        if (preg_match('"0 @(.*)@ INDI"', $value, $matches)) {
          $value = $matches[1];
        }
        else {
          $value = '';
        }
        break;

      case 'link';
        $value = $this->webtree_url;
        break;

      case 'name':
      case 'first':
      case 'last';
        // Looking for "1 NAME William George /Wong/".
        // Matches include full string and each element.
        $matches = [];
        $first = '';
        $last = '';
        preg_match('"1 NAME (.*) /(.*)/"', $value, $matches);
        switch (count($matches)) {
          case 0:
            return '';

          case 2:
            $first = $matches[1];
            break;

          default:
            $first = $matches[1];
            $last  = $matches[2];
            break;
        }

        switch ($format) {
          case 'first':
            $value = $first;
          case 'last';
            $value = $last;
          default:
            $value = "$first $last";
        }
        break;
    }

    return $value;
  }

}
